#' Write output
#'
#' Write the score data frame and plots of actual vs. predicted age for all reported gene sets to disk.
#'
#' @param results The results object returned by \code{\link{tempo.runInstance}}.
#' @param filename The prefix for the filename.  Writes filename.pdf and filename.table (a tab-delimited text file) for all reported gene sets
#' @export
tempo.writeOutput = function(results, filename) {
    tempo.mkplots(results, sprintf("%s%s",filename,".pdf"))
    write.table(results$scores[results$reported,],file=sprintf("%s%s",filename,".table"),quote=FALSE,sep="\t")
}

#' Make a plot for a specified gene sets
#'
#' Generate a plot of actual vs. predicted age, broken down by control sample or test sample, for a single specified gene set
#'
#' @param results The results object returned by \code{\link{tempo.runInstance}}.
#' @param geneset The name of a gene set
#' @export
tempo.mkplot = function(results,geneset){
  score = results$scores[geneset,"score"]
  ctrlResponse = results$Y[results$ctrl]
  testResponse = results$Y[results$test]
  ctrlPred = results$pred[geneset,results$ctrl]
  testPred = results$pred[geneset,results$test]
  yRange = c(min(ctrlResponse, testResponse)-1,max(c(ctrlResponse,testResponse)+1))
  par(mfrow=c(1,2),oma=c(4,4,2,0),mar=c(0,0,1,1))
  plot(ctrlResponse, ctrlPred, xlim = yRange, ylim = yRange, col = "red", main = "Control",axes=FALSE,asp=1)
  axis(side=1)
  axis(side=2)
  box()
  abline(0,1,lty=2)
  plot(testResponse, testPred, xlim = yRange, ylim = yRange, col = "blue", main = "Test",axes=FALSE,asp=1)
  axis(side=1)
  axis(side=2,labels=FALSE)
  box()
  abline(0,1,lty=2)
  title(main=sprintf("%s (Score: %f)", geneset, score), xlab = "Actual Age", ylab = "Predicted Age", outer=TRUE)
}

tempo.mkplots = function(results, fName) {
    pdf(fName, width=9.75, height=6)
    for (geneset in results$reported) {
        tempo.mkplot(results,geneset)
    }
    dev.off()
}
